Plot a single-arm Bayes factor design
Source:R/s3-singlearm_bf_design.R
plot.singlearm_bf_design.RdProduces a diagnostic plot for a fitted single-arm two-stage Bayes factor design. Depending on the available information in the object, the plot shows the interim-search results, selected operating characteristics, and the design and analysis priors under \(H_0\) and \(H_1\).
Usage
# S3 method for class 'singlearm_bf_design'
plot(x, ...)